struct Callsites {
list_head: AtomicPtr<DefaultCallsite>,
has_locked_callsites: AtomicBool,
}Fields
list_head: AtomicPtr<DefaultCallsite>has_locked_callsites: AtomicBoolImplementations
Sourceimpl Callsites
impl Callsites
Sourcefn rebuild_interest(&self, dispatchers: Rebuilder<'_>)
fn rebuild_interest(&self, dispatchers: Rebuilder<'_>)
Rebuild Interests for all callsites in the registry.
This also re-computes the max level hint.
Sourcefn push_dyn(&self, callsite: &'static dyn Callsite)
fn push_dyn(&self, callsite: &'static dyn Callsite)
Push a dyn Callsite trait object to the callsite registry.
This will attempt to lock the callsites vector.
Sourcefn push_default(&self, callsite: &'static DefaultCallsite)
fn push_default(&self, callsite: &'static DefaultCallsite)
Push a DefaultCallsite to the callsite registry.
If we know the callsite being pushed is a DefaultCallsite, we can push
it to the linked list without having to acquire a lock.